@@ -13,6 +13,10 @@ import numpy as np
 #                 fs, double type,emxArray_real_T *sig_out, double *delay, double *err)
 
 
+# void matchsig_2(const emxArray_real_T *ref, const emxArray_real_T *sig, double
+#                 fs, double type, emxArray_real_T *sig_out, double *delay, double
+#                 *err)
+
 # void matchsig_2(const emxArray_real_T *ref, const emxArray_real_T *sig, double
 #                 fs, double type, emxArray_real_T *sig_out, double *delay, double
 #                 *err)
@@ -64,6 +68,8 @@ def match_sig(refFile=None,testFile=None,outFile=None,audioType=1):
 
 
 if __name__ == '__main__':
-    print(match_sig(refFile='speech.wav', targetFile='test.wav', outFile='outfile.wav'))
+    ref = r'C:\Users\vcloud_avl\Documents\我的POPO\speech_cn_minus_6.wav'
+    test = r'C:\Users\vcloud_avl\Documents\我的POPO\cleDstFile_minus_6.wav'
+    print(match_sig(refFile=ref, testFile=test, outFile='outfile.wav'))
 
     pass
\ No newline at end of file
