@@ -15,14 +15,15 @@ from .SNR_ESTIMATION.SNR_TRANSIENT import cal_snr_transient
 from .AGC_EVALUATION.CAL_GAIN_TABLE import cal_gain_table
 from .AGC_EVALUATION.CAL_ATTACK_RELEASE import cal_attack_release
 from .AGC_EVALUATION.CAL_MUSIC_STABILITY import cal_music_stablility
+from .AGC_EVALUATION.CAL_DELAY import cal_DELAY
 from operator import methodcaller
 from .computeAudioQuality.mainProcess import computeAudioQuality
 
 from ctypes import  *
 
-def compute_audio_quality(metrics,testFile=None,refFile=None,cleFile=None,outFile=None,noiseFile=None,samplerate=16000,bitwidth=2,channel=1,refOffset=0,testOffset=0,maxComNLevel =-48.0,speechPauseLevel=-35.0,gaintableType=0):
+def compute_audio_quality(metrics,testFile=None,refFile=None,cleFile=None,outFile=None,noiseFile=None,samplerate=16000,bitwidth=2,channel=1,refOffset=0,testOffset=0,maxComNLevel =-48.0,speechPauseLevel=-35.0,audioType=0):
     """
-    :param metrics: G160/P563/POLQA/PESQ/STOI/STI/PEAQ/SDR/SII/LOUDNESS/MUSIC/MATCH/TRANSIENT/GAINTABLE/ATTACKRELEASE/MUSICSTA，必选项
+    :param metrics: G160/P563/POLQA/PESQ/STOI/STI/PEAQ/SDR/SII/LOUDNESS/MUSIC/MATCH/TRANSIENT/GAINTABLE/ATTACKRELEASE/MUSICSTA/AGCDELAY，必选项
     # G160 无采样率限制；  WAV/PCM输入 ；三端输入: clean、ref、test；无时间长度要求；
     # P563 8000hz(其他采样率会强制转换到8khz)；  WAV/PCM输入 ；单端输入: test；时长 < 20s；
     # POLQA 窄带模式  8k  超宽带模式 48k ；WAV/PCM输入 ；双端输入：ref、test；时长 < 20s；
@@ -37,6 +38,7 @@ def compute_audio_quality(metrics,testFile=None,refFile=None,cleFile=None,outFil
     # GAINTABLE 无采样率限制,WAV/PCM输入;双端输入：ref、test；固定信号输入；
     # ATTACKRELEASE 无采样率限制,WAV/PCM输入;双端输入：ref、test；固定信号输入；
     # MUSICSTA 无采样率限制,WAV/PCM输入;双端输入：ref、test；无时间长度要求；
+    # AGCDELAY 无采样率限制,WAV/PCM输入;双端输入：ref、test；无时间长度要求；
     不同指标输入有不同的采样率要求，如果传入的文件不符合该指标的要求，会自动变采样到合法的区间
     :param testFile: 被测文件，必选项
     :param refFile:  参考文件，可选项，全参考指标必选，比如POLQA/PESQ/PEAQ
@@ -48,6 +50,9 @@ def compute_audio_quality(metrics,testFile=None,refFile=None,cleFile=None,outFil
     :param channel: 通道数，可选项，pcm文件需要 default = 1
     :param refOffset: ref文件的样点偏移，可选项，指标G160需要
     :param testOffset: test文件的样点偏移，可选项，指标G160需要
+    :param maxComNLevel: 测试G160文件的最大舒适噪声
+    :param speechPauseLevel 测试G160文件的语音间歇段的噪声
+    :param audioType  输入音频的模式 0：语音 1：音乐
     :return:
     """
     paraDicts = {
@@ -64,7 +69,7 @@ def compute_audio_quality(metrics,testFile=None,refFile=None,cleFile=None,outFil
         'testOffset':testOffset,
         'maxComNLevel':maxComNLevel,
         "speechPauseLevel":speechPauseLevel,
-        "gaintableType":gaintableType
+        "audioType":audioType
     }
     comAuQUA = computeAudioQuality(**paraDicts)
     return methodcaller(metrics)(comAuQUA)
